==> xsystem35_2.13.0.orig.tar.gz: xsystem35-sdl2-2.13.0/game_compatibility.md <==
Game Compatibility
==================

|                 Game                        |   Status    | Notes |
| ------------------------------------------- | ----------- | ----- |
| 鬼畜王ランス                                | Supported   |       |
| Kichikuou Rance (EN)                        | Supported   |       |
| RanceIV －教団の遺産－                      | Supported   | Win95 edition and [Ver2.05](https://hannylaboratory.blogspot.com/2023/01/blog-post_26.html) |
| Rance4 -Legacy of the Sect- (EN)            | Supported   |       |
| 兰斯IV －教团的遗产－ (CN)                  | Supported   |       |
| ランス4.1                                   | Supported   | [Ver1.05](https://hannylaboratory.blogspot.com/2023/02/blog-post_9.html). Use system3-sdl2 for older versions |
| ランス4.2                                   | Supported   | [Ver1.05](https://hannylaboratory.blogspot.com/2023/02/blog-post_9.html). Use system3-sdl2 for older versions |
| いけないかつみ先生                          | Supported   | Emojis are not supported |
| 闘神都市II                                  | Supported   | Win95 edition |
| かえるにょ・ぱにょ～ん                      | Supported   | Normal / Low-priced edition |
| 戦巫女                                      | Supported   | Normal / Low-priced edition |
| 零式                                        | Supported   | From ALICEの館４・５・６ / Low-priced edition |
| アトラク＝ナクア                            | Supported   | From ALICEの館４・５・６ / Low-priced edition |
| Rance －光を求めて－                        | Supported   | From ALICEの館４・５・６ |
| Rance II －反逆の少女達－                   | Supported   | From ALICEの館４・５・６ |
| Rance III －リーザス陥落－                  | Supported   | From ALICEの館４・５・６ |
| DALK                                        | Supported   | From ALICEの館４・５・６ |
| 闘神都市                                    | Supported   | From ALICEの館４・５・６ |
| Dr.STOP                                     | Supported   | From ALICEの館４・５・６ |
| 人間狩り                                    | Supported   | From ALICEの館４・５・６ / アリスCD |
| 女の子図鑑                                  | Unknown     | From ALICEの館４・５・６ |
| 恋のおわり                                  | Unknown     |       |
| 王道勇者                                    | Supported   |       |
| AmbivalenZ                                  | Supported   | Win95 edition |
| DiaboLiQuE                                  | Supported   | Normal / Low-priced edition |
| 夢幻泡影                                    | Unknown     | Win98 edition |
| ぱすてるチャイム                            | Supported   | See [patch/README.TXT](patch/README.TXT) |
| ぷろすちゅーでんとGood                      | Supported   |       |
| 守り神様                                    | Supported   |       |
| ママトト                                    | Supported   |       |
| HUSHABY BABY                                | Supported   |       |
| DARCROWS                                    | Supported   |       |
| 隠れ月                                      | Supported   |       |
| PERSIOM                                     | Supported   | 3D sound is not supported |
| SeeIn青                                     | Supported   |       |
| かえるにょ国にょアリス                      | Supported   | From 20世紀アリス |
| これD・P・S？                               | Supported   | From 20世紀アリス |
| 夜が来る！                                  | Unsupported |       |
| Only you ～リ・クルス～                     | Supported   |       |
| 大悪司                                      | Supported   | Opening demo is not supported |
| 王子さまＬｖ１                              | Supported   |       |
| 王子さま１ヵ月後                            | Supported   | From 王子さまLV1.5 |
| 白鳳の子分叩き                              | Supported   | From 王子さまLV1.5 |
| チェシャのお部屋1.5                         | Supported   | From 王子さまLV1.5 |
| 王子さま１／１６                            | Supported   | From 王子さまLV1.5 |
| スパイ伊藤の「クイズ！俺にさぼらせろ」      | Supported   | From 王子さまLV1.5 |
| 妻みぐい                                    | Supported   | Opening demo is not supported |
| 超昂天使エスカレイヤー                      | Supported   | Opening demo is not supported |
| ランス５Ｄ                                  | Supported   |       |
| Rance 5D - The Lonely Girl (MangaGamer)     | Supported   |       |
| 俺の下であがけ                              | Unknown     |       |
| 楽園行                                      | Unknown     |       |
| 妻みぐい２                                  | Supported   |       |
| シェル・クレイル                            | Supported   |       |
| ナイトデーモン                              | Supported   |       |
| 学園KING                                    | Supported   | From アリスCD |
| 学園KING 番外編                             | Supported   | From アリスCD |
| 蒼海に墜ちて                                | Supported   | From アリスCD |
| ぶろぶろ                                    | Supported   | From アリスCD |
| 裸ぶろぶろ狂                                | Supported   | From アリスCD |
| メイドのススメ                              | Supported   | From アリスCD |
| 学園漂流戦記                                | Supported   | From アリスCD |
| 学園漂流戦記２                              | Supported   | From アリスCD |
| 当たって!!KUDAKERO 予告編                   | Supported   | From アリスCD |
| 妖精                                        | Supported   | From アリスCD |
| ［扉］                                      | Supported   | From アリスCD |
| 叩き殺し太郎                                | Supported   | From アリスCD |
| バルーンぽっぷ                              | Supported   | From アリスCD |
| 高速ひよこ２                                | Supported   | From アリスCD |
| おせろっと                                  | Supported   | From アリスCD |
| マスカレイド                                | Supported   | From アリスCD |
| キャロル ～聖なる鐘が響く夜～               | Supported   | From アリスCD, Online match is not supported |
| できるかなー？                              | Supported   | From アリスCD |
| Child Assassin                              | Unsupported | From アリスCD |
| Klavier                                     | Supported   | From アリスCD |
| 弱肉狂食                                    | Supported   | From アリスCD |
| 眼鏡大戦２                                  | Supported   | From アリスCD |
| 妄想くん                                    | Supported   | From アリスCD |

==> xsystem35_2.14.2.orig.tar.gz: xsystem35-sdl2-2.14.2/game_compatibility.md <==
Game Compatibility
==================

|                 Game                        |   Status    | Notes |
| ------------------------------------------- | ----------- | ----- |
| 鬼畜王ランス                                | Supported   |       |
| Kichikuou Rance (EN)                        | Supported   | Fan translation |
| RanceIV －教団の遺産－                      | Supported   | Win95 edition and [Ver2.05](https://hannylaboratory.blogspot.com/2023/01/blog-post_26.html) |
| Rance4 -Legacy of the Sect- (EN)            | Supported   | Fan translation |
| 兰斯IV －教团的遗产－ (CN)                  | Supported   | Fan translation |
| ランス4.1                                   | Supported   | [Ver1.05](https://hannylaboratory.blogspot.com/2023/02/blog-post_9.html). Use system3-sdl2 for older versions |
| ランス4.2                                   | Supported   | [Ver1.05](https://hannylaboratory.blogspot.com/2023/02/blog-post_9.html). Use system3-sdl2 for older versions |
| いけないかつみ先生                          | Supported   | Emojis are not supported |
| 闘神都市II                                  | Supported   | Win95 edition |
| かえるにょ・ぱにょ～ん                      | Supported   | Normal / Low-priced edition |
| 戦巫女                                      | Supported   | Normal / Low-priced edition |
| 零式                                        | Supported   | From ALICEの館４・５・６ / Low-priced edition |
| アトラク＝ナクア                            | Supported   | From ALICEの館４・５・６ / Low-priced edition |
| Rance －光を求めて－                        | Supported   | From ALICEの館４・５・６ |
| Rance II －反逆の少女達－                   | Supported   | From ALICEの館４・５・６ |
| Rance III －リーザス陥落－                  | Supported   | From ALICEの館４・５・６ |
| DALK                                        | Supported   | From ALICEの館４・５・６ |
| 闘神都市                                    | Supported   | From ALICEの館４・５・６ |
| Dr.STOP                                     | Supported   | From ALICEの館４・５・６ |
| 人間狩り                                    | Supported   | From ALICEの館４・５・６ / アリスCD |
| 女の子図鑑                                  | Unknown     | From ALICEの館４・５・６ |
| 恋のおわり                                  | Unknown     |       |
| 王道勇者                                    | Supported   |       |
| AmbivalenZ                                  | Supported   | Win95 edition |
| DiaboLiQuE                                  | Supported   | Normal / Low-priced edition |
| 夢幻泡影                                    | Unknown     | Win98 edition |
| ぱすてるチャイム                            | Supported   | See [patch/README.TXT](patch/README.TXT) |
| ぷろすちゅーでんとGood                      | Supported   |       |
| 守り神様                                    | Supported   |       |
| ママトト                                    | Supported   |       |
| HUSHABY BABY                                | Supported   |       |
| DARCROWS                                    | Supported   |       |
| 隠れ月                                      | Supported   |       |
| PERSIOM                                     | Supported   | 3D sound is not supported |
| SeeIn青                                     | Supported   |       |
| かえるにょ国にょアリス                      | Supported   | From 20世紀アリス |
| これD・P・S？                               | Supported   | From 20世紀アリス |
| 夜が来る！                                  | Unsupported |       |
| Only you ～リ・クルス～                     | Supported   |       |
| 大悪司                                      | Supported   | Opening demo is not supported |
| 王子さまＬｖ１                              | Supported   |       |
| 王子さま１ヵ月後                            | Supported   | From 王子さまLV1.5 |
| 白鳳の子分叩き                              | Supported   | From 王子さまLV1.5 |
| チェシャのお部屋1.5                         | Supported   | From 王子さまLV1.5 |
| 王子さま１／１６                            | Supported   | From 王子さまLV1.5 |
| スパイ伊藤の「クイズ！俺にさぼらせろ」      | Supported   | From 王子さまLV1.5 |
| 妻みぐい                                    | Supported   | Opening demo is not supported |
| 超昂天使エスカレイヤー                      | Supported   | Opening demo is not supported |
| ランス５Ｄ                                  | Supported   |       |
| Rance 5D - The Lonely Girl (EN)             | Supported   | MangaGamer version |
| 俺の下であがけ                              | Supported   |       |
| 楽園行                                      | Supported   |       |
| 妻みぐい２                                  | Supported   |       |
| シェル・クレイル                            | Supported   |       |
| ナイトデーモン                              | Supported   |       |
| 学園KING                                    | Supported   | From アリスCD |
| 学園KING 番外編                             | Supported   | From アリスCD |
| 蒼海に墜ちて                                | Supported   | From アリスCD |
| ぶろぶろ                                    | Supported   | From アリスCD |
| 裸ぶろぶろ狂                                | Supported   | From アリスCD |
| メイドのススメ                              | Supported   | From アリスCD |
| 学園漂流戦記                                | Supported   | From アリスCD |
| 学園漂流戦記２                              | Supported   | From アリスCD |
| 当たって!!KUDAKERO 予告編                   | Supported   | From アリスCD |
| 妖精                                        | Supported   | From アリスCD |
| ［扉］                                      | Supported   | From アリスCD |
| 叩き殺し太郎                                | Supported   | From アリスCD |
| バルーンぽっぷ                              | Supported   | From アリスCD |
| 高速ひよこ２                                | Supported   | From アリスCD |
| おせろっと                                  | Supported   | From アリスCD |
| マスカレイド                                | Supported   | From アリスCD |
| キャロル ～聖なる鐘が響く夜～               | Supported   | From アリスCD, Online match is not supported |
| できるかなー？                              | Supported   | From アリスCD |
| Child Assassin                              | Unsupported | From アリスCD |
| Klavier                                     | Supported   | From アリスCD |
| 弱肉狂食                                    | Supported   | From アリスCD |
| 眼鏡大戦２                                  | Supported   | From アリスCD |
| 妄想くん                                    | Supported   | From アリスCD |
